#!/bin/sh

echo "******************************************************************"
echo " HELIOS-FU"
echo " Fukuoka University"
echo " Created by Hidehisa Akiyama"
echo " Copyright Hidehisa Akiyama. All rights reserved."
echo "******************************************************************"


DIR=`dirname $0`

player="${DIR}/helios_player"
coach="${DIR}/helios_coach"
teamname="HELIOS-FU"
host="localhost"
port=6000
coach_port=""

player_conf="${DIR}/player.conf"
config_dir="${DIR}/formations-4231"
param_file="${DIR}/parameters/params"
intercept_conf_path="${DIR}/intercept_probability/"

max_chain_length="4"
max_evaluate_size="500"

coach_conf="${DIR}/coach.conf"
team_graphic="--use_team_graphic off"

number=11
usecoach="true"

unum=0

sleepprog=sleep
goaliesleep=1
sleeptime=0


usage()
{
  (echo "Usage: $0 [options]"
   echo "Available options:"
   echo "      --help                   prints this"
   echo "  -h, --host HOST              specifies server host (default: localhost)"
   echo "  -p, --port PORT              specifies server port (default: 6000)"
   echo "  -P  --coach-port PORT        specifies server port for online coach (default: 6002)"
   echo "  -t, --teamname TEAMNAME      specifies team name"
   echo "  -n, --number NUMBER          specifies the number of players"
   echo "  -u, --unum UNUM              specifies the invoked player/coach by uniform"
   echo "  -C, --without-coach          specifies not to run the coach"
   echo "  -f, --formation DIR          specifies the formation directory"
   echo "      --param-file FILE        specifies the parameter file"
   echo "      --max-chain-length N     specifies the maximum action chain length"
   echo "      --max-evaluate-size N    specifies the maximum action chain size to be evaluated"
   echo "      --intercept-conf-path DIR specifies the directory path for intercept conf files") 1>&2
}

while [ $# -gt 0 ]
do
  case $1 in

    --help)
      usage
      exit 0
      ;;

    -h|--host)
      if [ $# -lt 2 ]; then
        usage
        exit 1
      fi
      host="${2}"
      shift 1
      ;;

    -p|--port)
      if [ $# -lt 2 ]; then
        usage
        exit 1
      fi
      port="${2}"
      shift 1
      ;;

    -P|--coach-port)
      if [ $# -lt 2 ]; then
        usage
        exit 1
      fi
      coach_port="${2}"
      shift 1
      ;;

    -t|--teamname)
      if [ $# -lt 2 ]; then
        usage
        exit 1
      fi
      teamname="${2}"
      shift 1
      ;;

    -n|--number)
      if [ $# -lt 2 ]; then
        usage
        exit 1
      fi
      number="${2}"
      shift 1
      ;;

    -u|--unum)
      if [ $# -lt 2 ]; then
        usage
        exit 1
      fi
      unum="${2}"
      shift 1
      ;;

    -C|--without-coach)
      usecoach="false"
      ;;

    -f|--formation)
      if [ $# -lt 2 ]; then
        usage
        exit 1
      fi
      config_dir="${2}"
      shift 1
      ;;

    --param-file)
      if [ $# -lt 2 ]; then
        usage
        exit 1
      fi
      param_file="${2}"
      shift 1
      ;;

    --max-chain-length)
      if [ $# -lt 2 ]; then
        usage
        exit 1
      fi
      max_chain_length="${2}"
      shift 1
      ;;

    --max-evaluate-size)
      if [ $# -lt 2 ]; then
        usage
        exit 1
      fi
      max_evaluate_size="${2}"
      shift 1
      ;;

    --intercept-conf-path)
      if [ $# -lt 2 ]; then
        usage
        exit 1
      fi
      intercept_conf_path="${2}"
      shift 1
      ;;

    *)
      echo 1>&2
      echo "invalid option \"${1}\"." 1>&2
      echo 1>&2
      usage
      exit 1
      ;;
  esac

  shift 1
done

if [ X"${coach_port}" = X'' ]; then
  coach_port=`expr ${port} + 2`
fi

opt="--player-config ${player_conf} --config_dir ${config_dir}"
opt="${opt} -h ${host} -p ${port} -t ${teamname}"
opt="${opt} --param-file ${param_file}"
opt="${opt} --max-chain-length ${max_chain_length}"
opt="${opt} --max-evaluate-size ${max_evaluate_size}"
opt="${opt} --intercept-conf-path ${intercept_conf_path}"

ping -c 1 $host

if [ $number -gt 0 ]; then
  $player ${opt} -g &
  $sleepprog $goaliesleep
fi

i=2
while [ $i -le ${number} ] ; do
  $player ${opt} &
  $sleepprog $sleeptime
  i=`expr $i + 1`
done

if [ "${usecoach}" = "true" ]; then
  coachopt="--coach-config ${coach_conf}"
  coachopt="${coachopt} -h ${host} -p ${coach_port} -t ${teamname}"
  coachopt="${coachopt} ${team_graphic}"

  $coach ${coachopt} &
fi
